<!-- AUTO-GENERATED: scripts/generate_explanation_fragments.py -->
### Key Method Families (Generated)

| Family | Section Class | Description | Generated Reference |
|---|---|---|---|
| DFT | `DFT` | A base section used to define the parameters used in a density functional theory (DFT) calculation. | [Model Method Electronic](../../schema/model_method_electronic.md) |
| TB | `TB` | A base section containing the parameters pertaining to a tight-binding (TB) model calculation. | [Model Method Electronic](../../schema/model_method_electronic.md) |
| HF | `HF` | Defines a Hartree-Fock (HF) calculation. | [Model Method Electronic](../../schema/model_method_electronic.md) |
| CC | `CC` | A base section used to define the parameters of a Coupled Cluster calculation. | [Model Method Electronic](../../schema/model_method_electronic.md) |
| CI | `CI` | Single-reference Configuration Interaction (CI) methods using atom-centered basis sets. | [Model Method Electronic](../../schema/model_method_electronic.md) |
| Wannier | `Wannier` | A base section used to define the parameters used in a Wannier tight-binding fitting. | [Model Method Electronic](../../schema/model_method_electronic.md) |
| Slater-Koster | `SlaterKoster` | A base section used to define the parameters used in a Slater-Koster tight-binding fitting. | [Model Method Electronic](../../schema/model_method_electronic.md) |
| GW | `GW` | A base section used to define the parameters of a GW calculation. | [Model Method Electronic](../../schema/model_method_electronic.md) |
| BSE | `BSE` | A base section used to define the parameters of a BSE calculation. | [Model Method Electronic](../../schema/model_method_electronic.md) |
| DMFT | `DMFT` | A base section used to define the parameters of a DMFT calculation. | [Model Method Electronic](../../schema/model_method_electronic.md) |
| Excited-State Methodology | `ExcitedStateMethodology` | A base section used to define the parameters typical of excited-state calculations. | [Model Method Electronic](../../schema/model_method_electronic.md) |
| Photon | `Photon` | A base section used to define parameters of a photon, typically used for optical responses. | [Model Method Electronic](../../schema/model_method_electronic.md) |

Related generated references:
- [Model Method Electronic](../../schema/model_method_electronic.md)
- [Numerical Settings](../../schema/numerical_settings.md)
- [Force Field](../../schema/force_field.md)
